@@ -1,4 +1,4 @@
-det <- function(x, ...) UseMethod("det")
+determinant <- function(x, ...) UseMethod("determinant")
 eigen <- function(x, ...) UseMethod("eigen")
 expand <- function(x, ...) UseMethod("expand")
 expand.default <- function(x, ...) x
